use crate::types::user_interactive_authorization::UserInteractiveAuthorizationInfo;

#[derive(Debug, serde::Serialize)]
#[serde(untagged)]
pub enum RegistrationResponse {
    Success(RegistrationSuccess),
    UserInteractiveAuthorizationInfo(UserInteractiveAuthorizationInfo),
}

impl RegistrationResponse {
    pub fn user_interactive_authorization_info() -> Self {
        RegistrationResponse::UserInteractiveAuthorizationInfo(
            UserInteractiveAuthorizationInfo::new(),
        )
    }
}

#[derive(Debug, serde::Serialize)]
pub struct RegistrationSuccess {
    #[serde(skip_serializing_if = "Option::is_none")]
    access_token: Option<String>,
    device_id: String,
    user_id: String,
}

impl RegistrationSuccess {
    pub fn new(access_token: Option<&str>, device_id: &str, user_id: &str) -> Self {
        Self {
            access_token: access_token.and_then(|v| Some(v.to_owned())),
            device_id: device_id.to_owned(),
            user_id: user_id.to_owned(),
        }
    }
}
